@@ -14,11 +14,11 @@
 //! [orbiter]: https://en.wikipedia.org/wiki/Mars_Climate_Orbiter
 //!
 //! ## Usage
-//! `uom` requires `rustc` 1.60.0 or later. Add this to your `Cargo.toml`:
+//! `uom` requires `rustc` 1.65.0 or later. Add this to your `Cargo.toml`:
 //!
 //! ```toml
 //! [dependencies]
-//! uom = "0.35.0"
+//! uom = "0.36.0"
 //! ```
 //!
 //! and this to your crate root:
@@ -44,6 +44,9 @@
 //!     let velocity/*: Velocity*/ = length / time;
 //!     let _acceleration = calc_acceleration(velocity, time);
 //!     //let error = length + time; // error[E0308]: mismatched types
+//!
+//!     // Get a quantity value in a specific unit.
+//!     let time_in_nano_seconds = time.get::<uom::si::time::nanosecond>();
 //! }
 //!
 //! fn calc_acceleration(velocity: Velocity, time: Time) -> Acceleration {
@@ -66,7 +69,7 @@
 //! ```toml
 //! [dependencies]
 //! uom = {
-//!     version = "0.35.0",
+//!     version = "0.36.0",
 //!     default-features = false,
 //!     features = [
 //!         "autoconvert", # automatic base unit conversion.
@@ -77,7 +80,7 @@
 //!         "complex32", "complex64", # Complex floating point storage types.
 //!         "f32", "f64", # Floating point storage types.
 //!         "si", "std", # Built-in SI system and std library support.
-//!         "use_serde", # Serde support.
+//!         "serde", # Serde support.
 //!     ]
 //! }
 //! ```
@@ -95,17 +98,8 @@
 //!    default.
 //!  * `std` -- Feature to compile with standard library support. Disabling this feature compiles
 //!    `uom` with `no_std`. Enabled by default.
-//!  * `use_serde` -- Feature to enable support for serialization and deserialization of quantities
-//!    with the [Serde][serde] crate. Disabled by default.
-//!
-//!    [Serde][serde] support for the `big*` and `rational*` underlying storage types requires
-//!    manually enabling the `serde` feature for the `num-rational` and `num-bigint` crates. To do
-//!    so, you can add one or both of the following lines to your `Cargo.toml`:
-//!
-//!    ```toml
-//!    num-rational = { version = "*", features = ["serde"] }
-//!    num-bigint = { version = "*", features = ["serde"] }
-//!    ```
+//!  * `serde` -- Feature to enable support for serialization and deserialization of quantities with
+//!    the [Serde][serde] crate. Disabled by default.
 //!
 //! [si]: https://jcgm.bipm.org/vim/en/1.16.html
 //! [serde]: https://serde.rs/
@@ -426,25 +420,27 @@ pub trait Conversion<V> {
     type T: ConversionFactor<V>;
 
     /// Coefficient portion of [conversion factor](https://jcgm.bipm.org/vim/en/1.24.html) for
-    /// converting the given unit to the base unit for the quantity: `(value * coefficient()) +
-    /// constant()`. Implementation should return the multiplicative identity (`Self::T::one()`) if
-    /// no coefficient exists.
+    /// converting the given unit. To convert to the base unit for the quantity use `(value +
+    /// constant()) * coefficient()`. To convert from the base unit, `(value / coefficient()) -
+    /// constant()` is used. Implementation should return the multiplicative identity
+    /// (`Self::T::one()`) if no coefficient exists.
     #[must_use = "method returns a new number and does not mutate the original value"]
     #[inline(always)]
     fn coefficient() -> Self::T {
-        <Self::T as crate::num::One>::one()
+        <Self::T as num::One>::one()
     }
 
     /// Constant portion of [conversion factor](https://jcgm.bipm.org/vim/en/1.24.html) for
-    /// converting the given unit to the base unit for the quantity: `(value * coefficient()) +
-    /// constant()`. Implementation should return the additive identity (`Self::T::zero()`) if no
-    /// constant exists. See [ConstantOp](enum.ConstantOp.html) documentation for details about
-    /// parameter use to ensure the method optimizes correctly.
+    /// converting the given unit. To convert to the base unit for the quantity use `(value +
+    /// constant()) * coefficient()`. To convert from the base unit, `(value / coefficient()) -
+    /// constant()` is used. Implementation should return the additive identity (`Self::T::zero()`)
+    /// if no constant exists. See [`ConstantOp`] documentation for details about parameter use to
+    /// ensure the method optimizes correctly.
     #[must_use = "method returns a new number and does not mutate the original value"]
     #[inline(always)]
     #[allow(unused_variables)]
     fn constant(op: ConstantOp) -> Self::T {
-        <Self::T as crate::num::Zero>::zero()
+        <Self::T as num::Zero>::zero()
     }
 
     /// Instance [conversion factor](https://jcgm.bipm.org/vim/en/1.24.html).
@@ -522,8 +518,8 @@ pub trait Kind:
 storage_types! {
     types: Float;
 
-    impl crate::Conversion<V> for V {
-        type T = V;
+    impl crate::Conversion<Self> for V {
+        type T = Self;
 
         #[inline(always)]
         fn constant(op: crate::ConstantOp) -> Self::T {
@@ -539,14 +535,14 @@ storage_types! {
         }
     }
 
-    impl crate::ConversionFactor<V> for V {
+    impl crate::ConversionFactor<Self> for V {
         #[inline(always)]
         fn powi(self, e: i32) -> Self {
-            <V as crate::num::Float>::powi(self, e)
+            <Self as crate::num::Float>::powi(self, e)
         }
 
         #[inline(always)]
-        fn value(self) -> V {
+        fn value(self) -> Self {
             self
         }
     }
@@ -745,7 +741,7 @@ pub mod str {
 
     impl Display for ParseQuantityError {
         fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
-            use ParseQuantityError::*;
+            use ParseQuantityError::{NoSeparator, UnknownUnit, ValueParseError};
 
             match *self {
                 NoSeparator => write!(f, "no space between quantity and units"),
