@@ -1,6 +1,6 @@
 /// Macro to implement a [quantity][quantity] and associated [measurement units][measurement]. Note
-/// that this macro must be executed in direct submodules of the module where the
-/// [`system!`](macro.system.html) macro was executed. `@...` match arms are considered private.
+/// that this macro must be executed in direct submodules of the module where the [`system!`] macro
+/// was executed. `@...` match arms are considered private.
 ///
 /// * `$quantity_attr`: Quantity attributes. Generally used to set documentation comments for the
 ///   quantity.
@@ -13,7 +13,7 @@
 ///   represented as a `typenum` type-level integer (e.g. `N1`, `Z0`, `P1`, `P2`, ...).
 /// * `$kind`: [Kind][kind] of the quantity. Optional. This variable should only be specified when
 ///   defining a quantity that has the same dimensions as another quantity but isn't comparable.
-///   When not specified [`uom::Kind`](trait.Kind.html) is used.
+///   When not specified [`crate::Kind`] is used.
 /// * `$unit`: Unit name (e.g. `meter`, `foot`).
 /// * `$conversion`: Conversion (coefficient and constant factor) from the unit to the base unit of
 ///   the quantity (e.g. `3.048_E-1` to convert `foot` to `meter`. `1.0_E0, 273.15_E0` to convert
@@ -125,13 +125,14 @@ macro_rules! quantity {
         pub trait Unit: __system::Unit {}
 
         /// Trait to identify [units][units] which have a [conversion factor][factor] for the
-        /// `Quantity`. See [`Conversion<V>`](../../trait.Conversion.html).
+        /// `Quantity`. See [`crate::Conversion<V>`].
         ///
         /// ## Generic Parameters
         /// * `V`: Underlying storage type trait is implemented for.
         ///
         /// [units]: https://jcgm.bipm.org/vim/en/1.13.html
         /// [factor]: https://jcgm.bipm.org/vim/en/1.24.html
+        #[allow(dead_code)]
         pub trait Conversion<V>: Unit + $crate::Conversion<V, T = <V as $crate::Conversion<V>>::T>
         where
             V: $crate::Conversion<V>,
@@ -147,7 +148,7 @@ macro_rules! quantity {
         #[must_use = "method returns a static value"]
         #[allow(dead_code)]
         #[inline(always)]
-        pub fn description() -> &'static str {
+        pub const fn description() -> &'static str {
             $description
         }
 
@@ -337,7 +338,7 @@ macro_rules! quantity {
             /// * `N`: Unit.
             #[must_use = "method returns a new object"]
             pub fn format_args<N>(
-                unit: N,
+                _unit: N,
                 style: $crate::fmt::DisplayStyle
             ) -> __system::fmt::Arguments<Dimension, N>
             where
@@ -345,7 +346,7 @@ macro_rules! quantity {
             {
                 __system::fmt::Arguments {
                     dimension: $crate::lib::marker::PhantomData,
-                    unit,
+                    unit: $crate::lib::marker::PhantomData,
                     style,
                 }
             }
@@ -378,7 +379,7 @@ macro_rules! quantity {
             #[must_use = "method returns a new object and does not mutate the original one"]
             pub fn into_format_args<N>(
                 self,
-                unit: N,
+                _unit: N,
                 style: $crate::fmt::DisplayStyle
             ) -> __system::fmt::QuantityArguments<Dimension, U, V, N>
             where
@@ -387,7 +388,7 @@ macro_rules! quantity {
                 __system::fmt::QuantityArguments {
                     arguments: __system::fmt::Arguments {
                         dimension: $crate::lib::marker::PhantomData,
-                        unit,
+                        unit: $crate::lib::marker::PhantomData,
                         style,
                     },
                     quantity: self,
